I love timliao
==========


Inspired by iloveck101


How to install
==========

```bash
pip install ilovetim
```


How to use
==========

```bash
ilovetim [timliao url]
```


Example

```bash
ilovetim http://www.timliao.com/bbs/viewthread.php?tid=xxxxx
```


You could find account folder in ~/Pictures/`ilovetim`
